ca8045e6e4
commit 931d3de6c1c903cfd47842bc5026a9294ac492b4 Author: Siu Chi Chan <siuchi.chan@amd.com> Date: Mon Feb 13 10:54:06 2017 -0500 only force to libstdc++ if the g++ is older than version 5 since hcc already defaults to libstdc++ with newer g++ commit 1ef8d71aa788de7b9eead4906fe56186f06d7d3f Author: scchan <siuchi.chan@amd.com> Date: Sun Feb 12 14:44:11 2017 -0500 remove hardcoded -lc++ in tests commit 5d99ef338eb3a66523cc9ddd139e86c6fd707b9c Author: scchan <siuchi.chan@amd.com> Date: Sun Feb 12 14:35:46 2017 -0500 force include libstdc++ headers and stdc++ only if g++ version < 5 since hcc uses libstdc++ by default if g++ > 5 is present commit a2bc21b24d100feefe91cd3cb2271238bda0738a Author: scchan <siuchi.chan@amd.com> Date: Fri Feb 10 04:36:27 2017 -0500 use hcc-config to generate compiler and linker flags Change-Id: I13a79629c0adfd75439a47d0488ff4fd619c55ba (cherry picked from commit 866e744e40cf1378af8a679b54959bf5226c340f)
54 строки
1.7 KiB
C++
54 строки
1.7 KiB
C++
/*
|
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
|
|
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
of this software and associated documentation files (the "Software"), to deal
|
|
in the Software without restriction, including without limitation the rights
|
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
copies of the Software, and to permit persons to whom the Software is
|
|
furnished to do so, subject to the following conditions:
|
|
|
|
The above copyright notice and this permission notice shall be included in
|
|
all copies or substantial portions of the Software.
|
|
|
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
THE SOFTWARE.
|
|
*/
|
|
|
|
/* HIT_START
|
|
* BUILD: %t %s ../test_common.cpp
|
|
* RUN: %t
|
|
* HIT_END
|
|
*/
|
|
|
|
#include "hip/hip_runtime.h"
|
|
#include "test_common.h"
|
|
|
|
int main(int argc, char *argv[])
|
|
{
|
|
HipTest::parseStandardArguments(argc, argv, true);
|
|
|
|
HIPCHECK(hipInit(0));
|
|
|
|
hipDevice_t device;
|
|
hipDevice_t device1;
|
|
hipCtx_t ctx;
|
|
hipCtx_t ctx1;
|
|
|
|
HIPCHECK(hipDeviceGet(&device, 0));
|
|
HIPCHECK(hipCtxCreate(&ctx, 0, device));
|
|
HIPCHECK(hipCtxGetCurrent(&ctx1));
|
|
HIPCHECK(hipCtxGetDevice(&device1));
|
|
HIPCHECK(hipCtxPopCurrent(&ctx1));
|
|
HIPCHECK(hipCtxGetCurrent(&ctx1));
|
|
|
|
HIPCHECK(hipCtxDestroy(ctx));
|
|
|
|
passed();
|
|
};
|